Thanks for contributing! Please make sure your PR title and content follow the guidelines.
Leave this checklist below in your PR description and tick the corresponding boxes.

### Checklist

- [ ] Typing enforced
- [ ] Documentation updated
- [ ] Changelog updated
- [ ] Tests and Example updates
- [ ] Coverage should be 100%

### ✅ PR Title Format

Your PR title **must start with one of the following emojis** to indicate the type of change:

- 🐛 Bug fix
- 📄 Documentation
- 🎉 New feature or initial commit
- 🚀 Performance or deployment
- ♻️ Refactor or cleanup
- 📦 Packaging or dependency management (e.g., pyproject.toml, conda, Poetry, pre-commit)

**Example:**
🎉 Add MMD-based split method

---

### 📋 Description (optional)

Please explain what your PR does:

- What problem does it solve?
- Any breaking changes?
- How was it tested?

---

### 🔗 Related issues (optional)

Closes #___